@@ -1,23 +1,10 @@
-# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 # Copyright (C) 2010-2016 Red Hat, Inc.
 #
 # Authors:
 # Thomas Woerner <twoerner@redhat.com>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 # signal handling and run_server derived from setroubleshoot
 # Copyright (C) 2006,2007,2008,2009 Red Hat, Inc.
 # Authors:
@@ -25,19 +12,13 @@
 #   Thomas Liu  <tliu@redhat.com>
 #   Dan Walsh <dwalsh@redhat.com>
 
-__all__ = [ "run_server" ]
-
-import sys
 import signal
 
-# force use of pygobject3 in python-slip
-from gi.repository import GObject, GLib
-sys.modules['gobject'] = GObject
+from gi.repository import GLib
 
 import dbus
 import dbus.service
 import dbus.mainloop.glib
-import slip.dbus
 
 from firewall import config
 from firewall.core.logger import log
@@ -49,41 +30,53 @@ from firewall.server.firewalld import FirewallD
 #
 ############################################################################
 
+
 def sighup(service):
     service.reload()
     return True
 
+
 def sigterm(mainloop):
     mainloop.quit()
 
+
 ############################################################################
 #
 # run_server function
 #
 ############################################################################
 
+
 def run_server(debug_gc=False):
-    """ Main function for firewall server. Handles D-Bus and GLib mainloop.
-    """
+    """Main function for firewall server. Handles D-Bus and GLib mainloop."""
     service = None
     if debug_gc:
         from pprint import pformat
         import gc
+
         gc.enable()
         gc.set_debug(gc.DEBUG_LEAK)
 
         gc_timeout = 10
+
         def gc_collect():
             gc.collect()
             if len(gc.garbage) > 0:
-                print("\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
-                      ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n")
+                print(
+                    "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
+                    ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n"
+                )
                 print("GARBAGE OBJECTS (%d):\n" % len(gc.garbage))
                 for x in gc.garbage:
-                    print(type(x), "\n  ",)
+                    print(
+                        type(x),
+                        "\n  ",
+                    )
                     print(pformat(x))
-                print("\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<"
-                      "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n")
+                print(
+                    "\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<"
+                    "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n"
+                )
             GLib.timeout_add_seconds(gc_timeout, gc_collect)
 
     try:
@@ -93,27 +86,24 @@ def run_server(debug_gc=False):
         service = FirewallD(name, config.dbus.DBUS_PATH)
 
         mainloop = GLib.MainLoop()
-        slip.dbus.service.set_mainloop(mainloop)
         if debug_gc:
             GLib.timeout_add_seconds(gc_timeout, gc_collect)
 
         # use unix_signal_add if available, else unix_signal_add_full
-        if hasattr(GLib, 'unix_signal_add'):
+        if hasattr(GLib, "unix_signal_add"):
             unix_signal_add = GLib.unix_signal_add
         else:
             unix_signal_add = GLib.unix_signal_add_full
 
-        unix_signal_add(GLib.PRIORITY_HIGH, signal.SIGHUP,
-                        sighup, service)
-        unix_signal_add(GLib.PRIORITY_HIGH, signal.SIGTERM,
-                        sigterm, mainloop)
+        unix_signal_add(GLib.PRIORITY_HIGH, signal.SIGHUP, sighup, service)
+        unix_signal_add(GLib.PRIORITY_HIGH, signal.SIGTERM, sigterm, mainloop)
 
         mainloop.run()
 
-    except KeyboardInterrupt as e:
+    except KeyboardInterrupt:
         log.debug1("Stopping..")
 
-    except SystemExit as e:
+    except SystemExit:
         log.error("Raising SystemExit in run_server")
 
     except Exception as e:
